pub struct XdgDialogV1 { /* private fields */ }Expand description
dialog object
A xdg_dialog_v1 object is an ancillary object tied to a xdg_toplevel. Its purpose is hinting the compositor that the toplevel is a “dialog” (e.g. a temporary window) relative to another toplevel (see xdg_toplevel.set_parent). If the xdg_toplevel is destroyed, the xdg_dialog_v1 becomes inert.
Through this object, the client may provide additional hints about the purpose of the secondary toplevel. This interface has no effect on toplevels that are not attached to a parent toplevel.
See also the Request enum for this interface.